==> rswipl_9.3.21.zip: rswipl/NEWS.md <==
# rswipl 9.3.21

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-21/8879

Fixes a problem reported for r-oldrel-windows

# rswipl 9.3.20

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-20/8772

Avoids the use of non-API calls BODY, FORMALS.

# rswipl 9.3.18

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-18/8721

Fixes problems reported for reverse dependency _rolog_ under gcc-UBSAN

# rswipl 9.3.16

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-16/8645

Fixes a C23 compatibility issue

# rswipl 9.3.15

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-15/8613

# rswipl 9.3.13

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-13/8529

# rswipl 9.3.12

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-12/7803

Fixes problems with finding pack dlls under Windows.

# rswipl 9.3.11

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-11/7766

# rswipl 9.3.10

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-10/7728

Fixes some memory leaks by open queries.

# rswipl 9.3.8

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-8/7588

Workarounds for Rcpp::Language

# rswipl 9.3.7.2

Disable Rcpp::Language until SET-TYPEOF problem has been fixed.

# rswipl 9.3.7.1

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-7/7477

Add unit tests during installation, disable SIGUSR2 in Prolog

# rswipl 9.3.5.1

maintainance release, fixes problems reported for ASAN/UBSAN

# rswipl 9.3.5

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-5/7425

maintainance release, fixes problems reported for Alpine Linux

# rswipl 9.3.3.1

maintainance release, fixes problems reported for M1mac

remove unit tests from installation

# rswipl 9.3.3

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-3/7311

includes fix for RTools 4.4

# rswipl 9.3.2

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-2-2-9-3-2/7270

adds unit tests during installation

# rswipl 9.1.21

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-21/7075

# rswipl 9.1.20

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-20/7011

# rswipl 9.1.19

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-19/6978

# rswipl 9.1.18

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-18/6936

# rswipl 9.1.17.1

maintainance release, fixes UBSAN errors

# rswipl 9.1.17

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-17/6890

maintainance release, fixes linker warnings on MacOS

# rswipl 9.1.16

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-16/6862

maintainance release, fixes a problem with term.h on MacOS

# rswipl 9.1.15

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-15/6820

maintainance release, fixes valgrind issues

# rswipl 9.1.12

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-12/6754

maintainance release, fixes a problem with clang15 on macOS

# rswipl 9.1.11

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-11/6683

# rswipl 9.1.10

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-10/6562

# rswipl 9.1.9

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-9/6507

# rswipl 9.1.8

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-8/6400

fixed a warning under macOS

# rswipl 9.1.7

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-7/6332

# rswipl 9.1.6

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-6/6233

# rswipl 9.1.4

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-4/6136

# rswipl 9.1.3

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-3/6090

# rswipl 8.5.20

swipl-devel version 8.5.20

==> rswipl_10.0.0.zip: rswipl/NEWS.md <==
# rswipl 10.0.0

See https://swi-prolog.discourse.group/t/ann-swi-prolog-10-0-0-stable/

# rswipl 9.3.36

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-36/

# rswipl 9.3.35

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-35/

test\_installation is now part of the unit tests

# rswipl 9.3.34

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-34/

# rswipl 9.3.33

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-33/

# rswipl 9.3.31

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-31/

# rswipl 9.3.30

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-30/

# rswipl 9.3.29

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-29/

# rswipl 9.3.28

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-28/

# rswipl 9.3.27

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-27/

# rswipl 9.3.26

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-26/

# rswipl 9.3.25

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-25/

# rswipl 9.3.22

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-22/

# rswipl 9.3.21

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-21/

Fixes a problem reported for r-oldrel-windows

# rswipl 9.3.20

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-20/8772

Avoids the use of non-API calls BODY, FORMALS.

# rswipl 9.3.18

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-18/8721

Fixes problems reported for reverse dependency _rolog_ under gcc-UBSAN

# rswipl 9.3.16

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-16/8645

Fixes a C23 compatibility issue

# rswipl 9.3.15

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-15/8613

# rswipl 9.3.13

See https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-13/8529

# rswipl 9.3.12

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-12/7803

Fixes problems with finding pack dlls under Windows.

# rswipl 9.3.11

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-11/7766

# rswipl 9.3.10

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-10/7728

Fixes some memory leaks by open queries.

# rswipl 9.3.8

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-8/7588

Workarounds for Rcpp::Language

# rswipl 9.3.7.2

Disable Rcpp::Language until SET-TYPEOF problem has been fixed.

# rswipl 9.3.7.1

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-7/7477

Add unit tests during installation, disable SIGUSR2 in Prolog

# rswipl 9.3.5.1

maintainance release, fixes problems reported for ASAN/UBSAN

# rswipl 9.3.5

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-5/7425

maintainance release, fixes problems reported for Alpine Linux

# rswipl 9.3.3.1

maintainance release, fixes problems reported for M1mac

remove unit tests from installation

# rswipl 9.3.3

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-3-3/7311

includes fix for RTools 4.4

# rswipl 9.3.2

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-2-2-9-3-2/7270

adds unit tests during installation

# rswipl 9.1.21

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-21/7075

# rswipl 9.1.20

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-20/7011

# rswipl 9.1.19

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-19/6978

# rswipl 9.1.18

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-18/6936

# rswipl 9.1.17.1

maintainance release, fixes UBSAN errors

# rswipl 9.1.17

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-17/6890

maintainance release, fixes linker warnings on MacOS

# rswipl 9.1.16

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-16/6862

maintainance release, fixes a problem with term.h on MacOS

# rswipl 9.1.15

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-15/6820

maintainance release, fixes valgrind issues

# rswipl 9.1.12

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-12/6754

maintainance release, fixes a problem with clang15 on macOS

# rswipl 9.1.11

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-11/6683

# rswipl 9.1.10

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-10/6562

# rswipl 9.1.9

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-9/6507

# rswipl 9.1.8

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-8/6400

fixed a warning under macOS

# rswipl 9.1.7

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-7/6332

# rswipl 9.1.6

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-6/6233

# rswipl 9.1.4

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-4/6136

# rswipl 9.1.3

see https://swi-prolog.discourse.group/t/ann-swi-prolog-9-1-3/6090

# rswipl 8.5.20

swipl-devel version 8.5.20
